import axios from "axios";
import { localGet, localRemove } from '@/utils';
axios.defaults.withCredentials = true;
import { ElMessage } from "element-plus";
import router from "@/router/index";
axios.defaults.headers["X-Requested-With"] = "XMLHttpRequest";
axios.defaults.headers = {
  name: localGet('name'),
  token: localGet('token'),
};



// 请求拦截器，内部根据返回值，重新组装，统一管理。
axios.interceptors.response.use(
  (res) => {
    if(res.data.code === 2001||res.data.code === 2002) {
      ElMessage.error(res.data.message || "401 Unauthorized");
      router.push({ path: "/login" });
      localRemove('token');
      localRemove('name');
      return;
    }
    return res.data;
  },
  (error) => {
    ElMessage.closeAll();
    ElMessage.error(error || "请求错误");
    return Promise.reject(error);
  }
);
// post请求
export function postJsonRequest(url,action, params) {
  return axios({
    method: "post",
    url: url,
    data: params,
    headers: {
      "Content-Type": "application/json",
      action
    },
  });
}
export function downloadRequest(url, params) {
  return axios({
    method: "post",
    url: url,
    data: params,
    responseType: 'blob',
    headers: {
      "Content-Type": "application/json",
    },
  });
}
// get请求
export function getRequest(url, params) {
  return axios({
    method: "get",
    params: {
      ...params,
    },
    url: url,
  });
}

export function deleteRequest(url, params) {
  return axios({
    method: "delete",
    data: params,
    // responseType: 'arraybuffer',
    url: url,
  });
}
export const putRequest = (url, params) => {
  return axios({
    method: "put",
    data: params,
    // responseType: 'arraybuffer',
    url: url,
    headers: {
      "Content-Type": "application/json",
    },
  });
};
